@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://advcs.org
     Program ........ Notes
-    Version ........ 0.9
+    Version ........ 1.0
     Purpose ........ Storing Notes
 
 *******************************************************************************/
@@ -222,7 +222,7 @@ class Notes {
          $oldtitle = $oldnote[1];
          $oldtext = $oldnote[2];
       }
-      if ($this->notescount > $this->maxnotescount-1)
+      if ($this->maxnotescount > 0 && $this->notescount > $this->maxnotescount-1)
          $this->error=2;
       if ($this->maxnotessize > 0 && $this->maxnotessize < $this->size)
          $this->error = 4;
@@ -284,11 +284,11 @@ class Notes {
       @fclose($file);
 
       if ($this->maxnotessize > 0)
-         print "<tr><td><center>$this->notescount / $this->maxnotescount Notes</center></td><td colspan=2>&nbsp;</td><td><center>$this->size / $this->maxnotessize Bytes</center></td><td>&nbsp;</td></tr>\n";
+         print "<tr><td><center>$this->notescount" . ($this->maxnotescount > 0 ? " / $this->maxnotescount" : '') . " Notes</center></td><td colspan=2>&nbsp;</td><td><center>$this->size / $this->maxnotessize Bytes</center></td><td>&nbsp;</td></tr>\n";
       else
-         print "<tr><td><center>$this->notescount / $this->maxnotescount Notes</center></td><td colspan=2>&nbsp;</td><td><center>$this->size Bytes</center></td><td>&nbsp;</td></tr>\n";
+         print "<tr><td><center>$this->notescount" . ($this->maxnotescount > 0 ? " / $this->maxnotescount" : '') . " Notes</center></td><td colspan=2>&nbsp;</td><td><center>$this->size Bytes</center></td><td>&nbsp;</td></tr>\n";
       print "</table></center><br><br>\n";
-      if ($this->error == 0 && $this->maxnotessize > $this->size)
+      if ($this->error == 0 && ($this->maxnotessize == 0 || $this->maxnotessize > $this->size))
          print "<center><form method=post><input type=submit name=submit value='Add a Note'></form></center>\n";
    }
 
@@ -307,4 +307,4 @@ class Notes {
    }
 }
 
-?>
+?>
\ No newline at end of file
