@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://advcs.org
     Program ........ Notes
-    Version ........ 0.9
+    Version ........ 1.0
     Purpose ........ Storing Notes
 
 *******************************************************************************/
@@ -22,7 +22,7 @@ function notes() {
 }
 
 function notes_version() { 
-   return 0.9;
+   return '1.0';
 }
 
 ?>
